==> pomodoro_v0.1_source.tar.bz2: pomodoro_v0.1_source/dev_log.scm <==
(
 (settings
  (
   (timer_cycle
    (
     ((sort Pomodoro) (duration 0.15)
      (ticking_command "ogg123 ~/clock_ticking.ogv &>/dev/null")
      (ringing_command "ogg123 ~/bell_sound.ogv &>/dev/null"))
     ((sort Short_break) (duration 0.1)
      (ticking_command "ogg123 ~/clock_ticking.ogv &>/dev/null")
      (ringing_command "ogg123 ~/bell_sound.ogv &>/dev/null"))
     ((sort Pomodoro) (duration 25)
      (ticking_command "ogg123 ~/clock_ticking.ogv &>/dev/null")
      (ringing_command "ogg123 ~/bell_sound.ogv &>/dev/null"))
     ((sort Short_break) (duration 5)
      (ticking_command "ogg123 ~/clock_ticking.ogv &>/dev/null")
      (ringing_command "ogg123 ~/bell_sound.ogv &>/dev/null"))
     ((sort Pomodoro) (duration 25)
      (ticking_command "ogg123 ~/clock_ticking.ogv &>/dev/null")
      (ringing_command "ogg123 ~/bell_sound.ogv &>/dev/null"))
     ((sort Short_break) (duration 5)
      (ticking_command "ogg123 ~/clock_ticking.ogv &>/dev/null")
      (ringing_command "ogg123 ~/bell_sound.ogv &>/dev/null"))
     ((sort Pomodoro) (duration 25)
      (ticking_command "ogg123 ~/clock_ticking.ogv &>/dev/null")
      (ringing_command "ogg123 ~/bell_sound.ogv &>/dev/null"))
     ((sort Long_break) (duration 30)
      (ticking_command "ogg123 ~/clock_ticking.ogv &>/dev/null")
      (ringing_command "ogg123 ~/bell_sound.ogv &>/dev/null"))
     )
    )
   )
  )
 (tasks
  (
   ;; (((name "Task name") (description "Task description")
   ;;   (done_at ("2016-09-10T15:42:38")) (done_with (5)))
   ((name "Task 1") (description "Learn it!") (done_at "2017-09-10T16:06:41") (done_with 5) (day "5/2/17"))
   ((name "Task 2") (description "Some fields are optional") (done_with 3) (day "2/15/32"))
   ((name "Task 3") (description "three") (short_interruption 42) (day "2017-02-05"))
   ((name "Task 4") (description "four") (estimation 23))
   ((name "Task 5") (description "five") (day "2017-02-05"))
   ((name "Task 6") (description "Learn it!") (long_interruption 17) (short_interruption 87) (done_at "2016-09-10T16:06:41") (done_with 5) (day "2017-02-05"))
   ((name "Task 7") (description "Some fields are optional") (day "1/9/84"))
   ((name "Task 8") (description "three"))
   ((name "Task 9") (description "four"))
   ((name "Task 10") (description "five"))
   ((name "Task 11") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 12") (description "Some fields are optional") (day "8/12/14"))
   ((name "Task 13") (description "three"))
   ((name "Task 14") (description "four"))
   ((name "Task 15") (description "five"))
   ((name "Task 16") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 17") (description "Some fields are optional"))
   ((name "Task 18") (description "three"))
   ((name "Task 19") (description "four"))
   ((name "Task 20") (description "five"))
   ((name "Task 21") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 22") (description "Some fields are optional"))
   ((name "Task 23") (description "three"))
   ((name "Task 24") (description "four"))
   ((name "Task 25") (description "five"))
   ((name "Task 26") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 27") (description "Some fields are optional"))
   ((name "Task 28") (description "three"))
   ((name "Task 29") (description "four"))
   ((name "Task 30") (description "five"))
   ((name "Task 31") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 32") (description "Some fields are optional"))
   ((name "Task 33") (description "three"))
   ((name "Task 34") (description "four"))
   ((name "Task 35") (description "five"))
   ((name "Task 36") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 37") (description "Some fields are optional"))
   ((name "Task 38") (description "three"))
   ((name "Task 39") (description "four"))
   ((name "Task 40") (description "five"))
   ((name "Task 41") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 42") (description "Some fields are optional"))
   ((name "Task 43") (description "three"))
   ((name "Task 44") (description "four"))
   ((name "Task 45") (description "five"))
   ((name "Task 46") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 47") (description "Some fields are optional"))
   ((name "Task 48") (description "three"))
   ((name "Task 49") (description "four"))
   ((name "Task 50") (description "five"))
   ((name "Task 51") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 52") (description "Some fields are optional"))
   ((name "Task 53") (description "three"))
   ((name "Task 54") (description "four"))
   ((name "Task 55") (description "five"))
   ((name "Task 56") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 57") (description "Some fields are optional"))
   ((name "Task 58") (description "three"))
   ((name "Task 59") (description "four"))
   ((name "Task 60") (description "five"))
   ((name "Task 61") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 62") (description "Some fields are optional"))
   ((name "Task 63") (description "three"))
   ((name "Task 64") (description "four"))
   ((name "Task 65") (description "Last"))
   ))
 )

==> pomodoro_v0.2_source.tar.bz2: pomodoro_v0.2_source/dev_log.scm <==
(
 (settings
  (
   (timer_cycle
    (
     ((sort Pomodoro) (duration 0.15)
      (ticking_command "ogg123 ~/clock_ticking.ogv")
      (ringing_command "ogg123 ~/bell_sound.ogv"))
     ((sort Short_break) (duration 0.1)
      (ticking_command "ogg123 ~/clock_ticking.ogv")
      (ringing_command "ogg123 ~/bell_sound.ogv"))
     ((sort Pomodoro) (duration 0.15)
      (ticking_command "ogg123 ~/clock_ticking.ogv")
      (ringing_command "ogg123 ~/bell_sound.ogv"))
     ((sort Short_break) (duration 0.1)
      (ticking_command "ogg123 ~/clock_ticking.ogv")
      (ringing_command "ogg123 ~/bell_sound.ogv"))
     ((sort Pomodoro) (duration 0.15)
      (ticking_command "ogg123 ~/clock_ticking.ogv")
      (ringing_command "ogg123 ~/bell_sound.ogv"))
     ((sort Short_break) (duration 0.1)
      (ticking_command "ogg123 ~/clock_ticking.ogv")
      (ringing_command "ogg123 ~/bell_sound.ogv"))
     ((sort Pomodoro) (duration 0.15)
      (ticking_command "ogg123 ~/clock_ticking.ogv")
      (ringing_command "ogg123 ~/bell_sound.ogv"))
     ((sort Long_break) (duration 0.2)
      (ticking_command "ogg123 ~/clock_ticking.ogv")
      (ringing_command "ogg123 ~/bell_sound.ogv"))
     )
    )
   )
  )
 (tasks
  (
   ;; (((name "Task name") (description "Task description")
   ;;   (done_at ("2016-09-10T15:42:38")) (done_with (5)))
   ((name "Task 1") (description "Learn it!") (done_at "2017-09-10T16:06:41") (done_with 5) (day "5/2/17"))
   ((name "Task 2") (description "Some fields are optional") (done_with 3) (day "2/15/32"))
   ((name "Task 3") (description "three") (short_interruption 42) (day "2017-02-05"))
   ((name "Task 4") (description "four") (estimation 23))
   ((name "Task 5") (description "five") (day "2017-02-05"))
   ((name "Task 6") (description "Learn it!") (long_interruption 17) (short_interruption 87) (done_at "2016-09-10T16:06:41") (done_with 5) (day "2017-02-05"))
   ((name "Task 7") (description "Some fields are optional") (day "1/9/84"))
   ((name "Task 8"))
   ((name "Task 9"))
   ((name "Task 10"))
   ((name "Task 11") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 12") (description "Some fields are optional") (day "8/12/14"))
   ((name "Task 13"))
   ((name "Task 14"))
   ((name "Task 15"))
   ((name "Task 16") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 17") (description "Some fields are optional"))
   ((name "Task 18"))
   ((name "Task 19"))
   ((name "Task 20"))
   ((name "Task 21") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 22") (description "Some fields are optional"))
   ((name "Task 23"))
   ((name "Task 24"))
   ((name "Task 25"))
   ((name "Task 26") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 27") (description "Some fields are optional"))
   ((name "Task 28"))
   ((name "Task 29"))
   ((name "Task 30"))
   ((name "Task 31") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 32") (description "Some fields are optional"))
   ((name "Task 33"))
   ((name "Task 34"))
   ((name "Task 35"))
   ((name "Task 36") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 37") (description "Some fields are optional"))
   ((name "Task 38"))
   ((name "Task 39"))
   ((name "Task 40"))
   ((name "Task 41") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 42") (description "Some fields are optional"))
   ((name "Task 43"))
   ((name "Task 44"))
   ((name "Task 45"))
   ((name "Task 46") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 47") (description "Some fields are optional"))
   ((name "Task 48"))
   ((name "Task 49"))
   ((name "Task 50"))
   ((name "Task 51") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 52") (description "Some fields are optional"))
   ((name "Task 53"))
   ((name "Task 54"))
   ((name "Task 55"))
   ((name "Task 56") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 57") (description "Some fields are optional"))
   ((name "Task 58"))
   ((name "Task 59"))
   ((name "Task 60"))
   ((name "Task 61") (description "Learn it!") (done_at "2016-09-10T16:06:41") (done_with 5))
   ((name "Task 62") (description "Some fields are optional"))
   ((name "Task 63"))
   ((name "Task 64"))
   ((name "Task 65") (description "Last"))
   ))
 )
